==> libreoffice-fresh-sdk-7.6.0-3-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/classes_15.js <==
var searchData=
[
  ['validatablebindablecontrolmodel_0',['ValidatableBindableControlModel',['../servicecom_1_1sun_1_1star_1_1form_1_1validation_1_1ValidatableBindableControlModel.html',1,'com::sun::star::form::validation']]],
  ['validatablecontrolmodel_1',['ValidatableControlModel',['../servicecom_1_1sun_1_1star_1_1form_1_1validation_1_1ValidatableControlModel.html',1,'com::sun::star::form::validation']]],
  ['valuebinding_2',['ValueBinding',['../servicecom_1_1sun_1_1star_1_1form_1_1binding_1_1ValueBinding.html',1,'com::sun::star::form::binding']]],
  ['valuepair_3',['ValuePair',['../structcom_1_1sun_1_1star_1_1animations_1_1ValuePair.html',1,'com::sun::star::animations']]],
  ['vbaeventprocessor_4',['VBAEventProcessor',['../servicecom_1_1sun_1_1star_1_1script_1_1vba_1_1VBAEventProcessor.html',1,'com::sun::star::script::vba']]],
  ['vbamacroresolver_5',['VBAMacroResolver',['../servicecom_1_1sun_1_1star_1_1script_1_1vba_1_1VBAMacroResolver.html',1,'com::sun::star::script::vba']]],
  ['vbascriptevent_6',['VBAScriptEvent',['../structcom_1_1sun_1_1star_1_1script_1_1vba_1_1VBAScriptEvent.html',1,'com::sun::star::script::vba']]],
  ['vbaspreadsheeteventprocessor_7',['VBASpreadsheetEventProcessor',['../servicecom_1_1sun_1_1star_1_1script_1_1vba_1_1VBASpreadsheetEventProcessor.html',1,'com::sun::star::script::vba']]],
  ['vbatexteventprocessor_8',['VBATextEventProcessor',['../servicecom_1_1sun_1_1star_1_1script_1_1vba_1_1VBATextEventProcessor.html',1,'com::sun::star::script::vba']]],
  ['vclcontainerevent_9',['VclContainerEvent',['../structcom_1_1sun_1_1star_1_1awt_1_1VclContainerEvent.html',1,'com::sun::star::awt']]],
  ['verb_10',['Verb',['../structcom_1_1sun_1_1star_1_1frame_1_1status_1_1Verb.html',1,'com::sun::star::frame::status']]],
  ['verbdescriptor_11',['VerbDescriptor',['../structcom_1_1sun_1_1star_1_1embed_1_1VerbDescriptor.html',1,'com::sun::star::embed']]],
  ['versionexception_12',['VersionException',['../exceptioncom_1_1sun_1_1star_1_1deployment_1_1VersionException.html',1,'com::sun::star::deployment']]],
  ['vertorientationformat_13',['VertOrientationFormat',['../structcom_1_1sun_1_1star_1_1text_1_1VertOrientationFormat.html',1,'com::sun::star::text']]],
  ['vetoexception_14',['VetoException',['../exceptioncom_1_1sun_1_1star_1_1util_1_1VetoException.html',1,'com::sun::star::util']]],
  ['view_15',['View',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1View.html',1,'com::sun::star::sdbcx']]],
  ['viewdescriptor_16',['ViewDescriptor',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1ViewDescriptor.html',1,'com::sun::star::sdbcx']]],
  ['viewsettings_17',['viewsettings',['../servicecom_1_1sun_1_1star_1_1text_1_1ViewSettings.html',1,'ViewSettings'],['../servicecom_1_1sun_1_1star_1_1view_1_1ViewSettings.html',1,'ViewSettings']]],
  ['viewstate_18',['ViewState',['../structcom_1_1sun_1_1star_1_1rendering_1_1ViewState.html',1,'com::sun::star::rendering']]],
  ['visibility_19',['Visibility',['../structcom_1_1sun_1_1star_1_1frame_1_1status_1_1Visibility.html',1,'com::sun::star::frame::status']]],
  ['visualrepresentation_20',['VisualRepresentation',['../structcom_1_1sun_1_1star_1_1embed_1_1VisualRepresentation.html',1,'com::sun::star::embed']]],
  ['vndsunstarpkgurlreferencefactory_21',['VndSunStarPkgUrlReferenceFactory',['../servicecom_1_1sun_1_1star_1_1uri_1_1VndSunStarPkgUrlReferenceFactory.html',1,'com::sun::star::uri']]],
  ['volatilecontentdestroyedexception_22',['VolatileContentDestroyedException',['../exceptioncom_1_1sun_1_1star_1_1rendering_1_1VolatileContentDestroyedException.html',1,'com::sun::star::rendering']]],
  ['volatileresult_23',['VolatileResult',['../servicecom_1_1sun_1_1star_1_1sheet_1_1VolatileResult.html',1,'com::sun::star::sheet']]]
];

==> libreoffice-fresh-sdk-25.8.4-2-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/classes_15.js <==
var searchData=
[
  ['validatablebindablecontrolmodel_0',['ValidatableBindableControlModel',['../servicecom_1_1sun_1_1star_1_1form_1_1validation_1_1ValidatableBindableControlModel.html',1,'com::sun::star::form::validation']]],
  ['validatablecontrolmodel_1',['ValidatableControlModel',['../servicecom_1_1sun_1_1star_1_1form_1_1validation_1_1ValidatableControlModel.html',1,'com::sun::star::form::validation']]],
  ['valuebinding_2',['ValueBinding',['../servicecom_1_1sun_1_1star_1_1form_1_1binding_1_1ValueBinding.html',1,'com::sun::star::form::binding']]],
  ['valuepair_3',['ValuePair',['../structcom_1_1sun_1_1star_1_1animations_1_1ValuePair.html',1,'com::sun::star::animations']]],
  ['vbaeventprocessor_4',['VBAEventProcessor',['../servicecom_1_1sun_1_1star_1_1script_1_1vba_1_1VBAEventProcessor.html',1,'com::sun::star::script::vba']]],
  ['vbamacroresolver_5',['VBAMacroResolver',['../servicecom_1_1sun_1_1star_1_1script_1_1vba_1_1VBAMacroResolver.html',1,'com::sun::star::script::vba']]],
  ['vbascriptevent_6',['VBAScriptEvent',['../structcom_1_1sun_1_1star_1_1script_1_1vba_1_1VBAScriptEvent.html',1,'com::sun::star::script::vba']]],
  ['vbaspreadsheeteventprocessor_7',['VBASpreadsheetEventProcessor',['../servicecom_1_1sun_1_1star_1_1script_1_1vba_1_1VBASpreadsheetEventProcessor.html',1,'com::sun::star::script::vba']]],
  ['vbatexteventprocessor_8',['VBATextEventProcessor',['../servicecom_1_1sun_1_1star_1_1script_1_1vba_1_1VBATextEventProcessor.html',1,'com::sun::star::script::vba']]],
  ['vclcontainerevent_9',['VclContainerEvent',['../structcom_1_1sun_1_1star_1_1awt_1_1VclContainerEvent.html',1,'com::sun::star::awt']]],
  ['verb_10',['Verb',['../structcom_1_1sun_1_1star_1_1frame_1_1status_1_1Verb.html',1,'com::sun::star::frame::status']]],
  ['verbdescriptor_11',['VerbDescriptor',['../structcom_1_1sun_1_1star_1_1embed_1_1VerbDescriptor.html',1,'com::sun::star::embed']]],
  ['versionexception_12',['VersionException',['../exceptioncom_1_1sun_1_1star_1_1deployment_1_1VersionException.html',1,'com::sun::star::deployment']]],
  ['vertorientationformat_13',['VertOrientationFormat',['../structcom_1_1sun_1_1star_1_1text_1_1VertOrientationFormat.html',1,'com::sun::star::text']]],
  ['vetoexception_14',['VetoException',['../exceptioncom_1_1sun_1_1star_1_1util_1_1VetoException.html',1,'com::sun::star::util']]],
  ['view_15',['View',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1View.html',1,'com::sun::star::sdbcx']]],
  ['viewdescriptor_16',['ViewDescriptor',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1ViewDescriptor.html',1,'com::sun::star::sdbcx']]],
  ['viewsettings_17',['ViewSettings',['../servicecom_1_1sun_1_1star_1_1text_1_1ViewSettings.html',1,'ViewSettings'],['../servicecom_1_1sun_1_1star_1_1view_1_1ViewSettings.html',1,'ViewSettings']]],
  ['viewstate_18',['ViewState',['../structcom_1_1sun_1_1star_1_1rendering_1_1ViewState.html',1,'com::sun::star::rendering']]],
  ['visibility_19',['Visibility',['../structcom_1_1sun_1_1star_1_1frame_1_1status_1_1Visibility.html',1,'com::sun::star::frame::status']]],
  ['visualrepresentation_20',['VisualRepresentation',['../structcom_1_1sun_1_1star_1_1embed_1_1VisualRepresentation.html',1,'com::sun::star::embed']]],
  ['vndsunstarpkgurlreferencefactory_21',['VndSunStarPkgUrlReferenceFactory',['../servicecom_1_1sun_1_1star_1_1uri_1_1VndSunStarPkgUrlReferenceFactory.html',1,'com::sun::star::uri']]],
  ['volatilecontentdestroyedexception_22',['VolatileContentDestroyedException',['../exceptioncom_1_1sun_1_1star_1_1rendering_1_1VolatileContentDestroyedException.html',1,'com::sun::star::rendering']]],
  ['volatileresult_23',['VolatileResult',['../servicecom_1_1sun_1_1star_1_1sheet_1_1VolatileResult.html',1,'com::sun::star::sheet']]]
];
